package com.atguigu.auth.controller;

import com.atguigu.auth.service.SysRoleService;
import com.atguigu.common.result.Result;
import com.atguigu.model.system.RoleByUser;
import com.atguigu.model.system.SysRole;
import com.atguigu.vo.system.AssginRoleVo;
import com.atguigu.vo.system.SysRoleQueryVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.ApiOperation;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@Tag(name = "角色管理接口")
@RestController
@RequestMapping("/admin/system/sysRole")
public class SysRoleController {
    @Autowired
    private SysRoleService sysRoleService;

    @Operation(summary = "查询全部角色列表", description = "查询全部角色列表")
    @GetMapping("findAll")
    public Result<List<SysRole>> findAll() {
        List<SysRole> sysRoleList = sysRoleService.list();
        return Result.success(sysRoleList);
    }

    @Operation(summary = "角色条件分页查询", description = "角色条件分页查询")
    @GetMapping("{page}/{limit}")
    public Result<IPage<SysRole>> pageResult(@PathVariable Long page, @PathVariable Long limit, SysRoleQueryVo sysRoleQueryVo) {
        IPage<SysRole> sysRoleIPage = sysRoleService.pageResult(page, limit, sysRoleQueryVo);
        return Result.success(sysRoleIPage);
    }

    @Operation(summary = "新增角色", description = "新增角色")
    @PostMapping("save")
    public Result<SysRole> save(@RequestBody SysRole sysRole) {
        sysRoleService.save(sysRole);
        return Result.success();
    }

    @Operation(summary = "修改角色", description = "修改角色")
    @PutMapping("update")
    public Result<SysRole> update(@RequestBody SysRole sysRole) {
        sysRoleService.updateById(sysRole);
        return Result.success();
    }

    @Operation(summary = "删除角色", description = "删除角色")
    @ApiOperation(value = "删除角色")
    @DeleteMapping("remove/{id}")
    public Result<SysRole> remove(@PathVariable Long id) {
        sysRoleService.removeById(id);
        return Result.success();
    }

    @Operation(summary = "根据id列表删除", description = "根据id列表删除")
    @DeleteMapping("batchRemove")
    public Result<SysRole> batchRemove(@RequestBody List<Long> idList) {
        sysRoleService.removeByIds(idList);
        return Result.success();
    }

    @ApiOperation(value = "根据用户获取角色数据")
    @GetMapping("/toAssign/{userId}")
    public Result<RoleByUser> toAssign(@PathVariable Long userId) {
        RoleByUser roleMap = sysRoleService.findRoleByAdminId(userId);
        return Result.success(roleMap);
    }

    @ApiOperation(value = "根据用户分配角色")
    @PostMapping("/doAssign")
    public Result<AssginRoleVo> doAssign(@RequestBody AssginRoleVo assginRoleVo) {
        sysRoleService.doAssign(assginRoleVo);
        return Result.success();
    }
}
