package com.atguigu.auth.controller;


import com.atguigu.auth.service.SysUserService;
import com.atguigu.common.result.Result;
import com.atguigu.model.system.SysUser;
import com.atguigu.vo.system.SysUserQueryVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 用户表 前端控制器
 * </p>
 *
 * @author bunny
 * @since 2024-04-22
 */
@Tag(name = "用户管理接口")
@RestController
@RequestMapping("/admin/system/sysUser")
public class SysUserController {
    @Autowired
    private SysUserService sysUserService;

    @Operation(summary = "用户条件分页查询", description = "用户条件分页查询")
    @GetMapping("{page}/{limit}")
    public Result<IPage<SysUser>> getUserByPage(@PathVariable Long page,
                                                @PathVariable Long limit,
                                                SysUserQueryVo sysUserQueryVo) {
        IPage<SysUser> pageModel = sysUserService.getUserByPage(page, limit, sysUserQueryVo);
        return Result.success(pageModel);
    }

    @Operation(summary = "获取用户", description = "获取用户")
    @GetMapping("get/{id}")
    public Result<SysUser> getById(@PathVariable Long id) {
        SysUser sysUser = sysUserService.getById(id);
        return Result.success(sysUser);
    }

    @Operation(summary = "保存用户", description = "保存用户")
    @PostMapping("save")
    public Result<SysUser> save(@RequestBody SysUser user) {
        sysUserService.save(user);
        return Result.success();
    }

    @Operation(summary = "更新用户", description = "更新用户")
    @PutMapping("update")
    public Result<SysUser> update(@RequestBody SysUser user) {
        sysUserService.updateById(user);
        return Result.success();
    }

    @Operation(summary = "删除用户", description = "删除用户")
    @DeleteMapping("remove/{id}")
    public Result<SysUser> remove(@PathVariable Long id) {
        sysUserService.removeById(id);
        return Result.success();
    }

    @Operation(summary = "批量删除用户", description = "批量删除用户")
    @DeleteMapping("batchRemove")
    public Result<SysUser> batchRemove(@RequestBody List<Long> idList) {
        sysUserService.removeByIds(idList);
        return Result.success();
    }
}

