package com.atguigu.auth.service.impl;


import com.atguigu.auth.mapper.SysRoleMapper;
import com.atguigu.auth.mapper.SysUserRoleMapper;
import com.atguigu.auth.service.SysRoleService;
import com.atguigu.model.system.RoleByUser;
import com.atguigu.model.system.SysRole;
import com.atguigu.vo.system.AssginRoleVo;
import com.atguigu.vo.system.SysRoleQueryVo;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.List;

@Service
public class SysRoleServiceImpl extends ServiceImpl<SysRoleMapper, SysRole> implements SysRoleService {
    @Autowired
    private SysUserRoleMapper sysUserRoleMapper;

    /**
     * 角色条件分页查询
     *
     * @param page  当前页
     * @param limit 每页记录数
     * @param vo    查询条件
     * @return 分页结果
     */
    @Override
    public IPage<SysRole> pageResult(Long page, Long limit, SysRoleQueryVo vo) {
        Page<SysRole> pageParam = new Page<>(page, limit);

        String roleName = vo.getRoleName();
        LambdaQueryWrapper<SysRole> wrapper = new LambdaQueryWrapper<>();
        wrapper.like(!StringUtils.isEmpty(roleName), SysRole::getRoleName, roleName);

        return page(pageParam, wrapper);
    }

    /**
     * 根据用户获取角色数据
     *
     * @param userId 用户id
     * @return 用户角色集合
     */
    @Override
    public RoleByUser findRoleByAdminId(Long userId) {
        // 查询所有角色
        List<SysRole> allRolesList = list();

        // 根据用户id查询所有的角色
        List<SysRole> assginRoleList = baseMapper.selectByUserId(userId);
        return RoleByUser.builder().allRolesList(allRolesList).assginRoleList(assginRoleList).build();
    }

    /**
     * 根据用户分配角色
     *
     * @param vo 分配条件
     */
    @Override
    public void doAssign(AssginRoleVo vo) {

    }
}
